===============
Getting Started
===============

This section will guide you through the installation of the `holisticai` open-source library and the first steps to get you started.

.. grid:: 3 3 3 3
   :gutter: 4
   :padding: 2 2 0 0
   :class-container: sd-text-center

   .. grid-item-card:: Install
         :link: install.html
         :shadow: md

         Installation and customizations, workaround and troubleshooting.

   .. grid-item-card:: Quickstart
         :link: quickstart.ipynb
         :shadow: md

         Quickstart guide to get you started with the library.

   .. grid-item-card:: Datasets
         :link: datasets.html
         :shadow: md
           
         Datasets and artifacts available in the library.

   .. grid-item-card:: Bias
         :link: bias/index.html
         :shadow: md

         Bias metrics and mitigation techniques.

   .. grid-item-card:: Explainability
         :link: explainability/index.html
         :shadow: md
            
         Explainability metrics and techniques.          

   .. grid-item-card:: Security
         :link: security/index.html
         :shadow: md
            
         Security metrics and mitigation techniques.          
        

.. If you update this toctree, also update the manual toctree in the
.. main index.rst.template

.. toctree::
   :hidden:

   install
   quickstart.ipynb
   datasets
   bias/index
   explainability/index
   security/index